// mozileMouse.js

/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Playsophy code.
 *
 * The Initial Developer of the Original Code is Playsophy
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *		Karl Guertin <grayrest@grayrest.com>
 *		James A. Overton <james@overton.ca>
 *		Christian Stocker (Bitflux)
 *		Paul Everitt
 *		David Palm
 *
 * ***** END LICENSE BLOCK ***** */

/*******

Mozile Mouse Javascript
Mozile version 0.61

Created by James A. Overton
Created on 2004-03-24

Last revised by James A. Overton
Last revised on 2004-04-17

HISTORY:
	Some code in this file was first found in mozilehtmltb.js, while the 
majority was cut out of mozileTB.js and separated into different files.


DESCRIPTION:
	This file is responsible for handling the mouse events.

*********/


/********* Handler *********/

// Listen for clicks, and then decide whether or not the Mozile toolbar needs to be shown or hidden
document.addEventListener("click", mozileMouse, false);



// Mozile Mouse
// Handles mouse click events
// Decides whether to autohide the toolbar, and when to activate the caret.

function mozileMouse(event) {
	var f = ["mozileMouse.js","mozileMouse"];

	mozileDebug(f,3,"Tag "+event.target.tagName);
		// this fixes an annoying bug, where clicking on a tab could unhide the toolbar.
	if(event.target.tagName=="tabbrowser") {
		return;
	}

	
		// if the target of the click is one of these, then don't change the status of the toolbar
	var protect = new Array( 'toolbar', 'toolbarbutton', 'menuitem', 'menu', 'colorpicker');
	for(var i=0; i<protect.length; i++) {
		if(event.target.tagName==protect[i]) {
			return;
		}
	}

		// set the toolbar and autohide variables
	if(mozileToolbar=="") {
		mozileToolbar = document.getElementById("mozile-toolbar");
	}
	
	mozileAutohide = mozilePrefs.getBoolPref('mozile.autohideBool');		// the Mozilla preference which enables autohide

	mozileCaret = mozilePrefs.getBoolPref('mozile.caretAlwaysOnBool');		// the Mozilla preference which enables caret browsing by default
	

		// if one of the tags on this list has been clicked on, then focus it. Fixes another bug.
	var focusList = new Array("input","textarea");
	for(var i=0; i<focusList.length; i++) {
		if(event.target.tagName.toLowerCase()==focusList[i]) {
			event.target.focus();
			
		if(!mozileToolbar.collapsed && mozileAutohide)	{
			mozileToolbar.collapsed = !mozileToolbar.collapsed;		// hide toolbar
		}
		mozilePrefs.setBoolPref('accessibility.browsewithcaret', mozileCaret);		// restore the default caret state
		
			return;
		}
	}

		// if Mozile is detected, then show the toolbar if it is hidden, and turn the caret on
	if(mozileDetect()) {
		if(mozileToolbar.collapsed) {
			mozileToolbar.collapsed = !mozileToolbar.collapsed;		// show toolbar
		}
		mozilePrefs.setBoolPref('accessibility.browsewithcaret', true);
	}
		// if Mozile is not detected, then hide the toolbar (if autohide is on) and restore the caret state.
	else {
		if(!mozileToolbar.collapsed && mozileAutohide)	{
			mozileToolbar.collapsed = !mozileToolbar.collapsed;		// hide toolbar
		}
		mozilePrefs.setBoolPref('accessibility.browsewithcaret', mozileCaret);		// restore the default caret state
	}


} // end mozileMouse


